==> TuxGuitar-0.3.tar.gz: TuxGuitar-0.3/src/org/herac/tuxguitar/song/models/SongTrack.java <==
/*
 * Created on 23-nov-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.song.models;

import java.io.Serializable;
import java.util.List;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SongTrack implements Serializable{
    private int channel;
    private int instrument;    
    private List measures;
    private List strings;
        
    public SongTrack(int channel,int instrument, List measures,List strings) {
        this.channel = channel;
        this.instrument = instrument;
        this.measures = measures;
        this.strings = strings;
    }
        
    public int getInstrument() {
        return instrument;
    }
    public void setInstrument(int instrument) {
        this.instrument = instrument;
    }
    public List getMeasures() {
        return measures;
    }
    public void setMeasures(List measures) {
        this.measures = measures;
    }    
    public int getChannel() {
        return channel;
    }
    public void setChannel(int channel) {
        this.channel = channel;
    }
    
    public List getStrings() {
        return strings;
    }
    public void setStrings(List strings) {
        this.strings = strings;
    }
    
    public boolean isPercusionTrack(){
        return (getChannel() == getDefaultPercusionChannel());
    }

    
    public static int getDefaultPercusionChannel(){
        return 9;
    }
}

==> TuxGuitar-0.4.1.tar.gz: TuxGuitar-0.4.1/src/org/herac/tuxguitar/song/models/SongTrack.java <==
/*
 * Created on 23-nov-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.song.models;

import java.io.Serializable;
import java.util.List;
/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SongTrack implements Serializable{
    private int channel;
    private int instrument;    
    private String name;
    private List measures;
    private List strings;
    private TrackColor color;    
    
    public SongTrack(String name,int channel,int instrument, List measures,List strings,TrackColor color) {
        this.name = name;
    	this.channel = channel;
        this.instrument = instrument;
        this.measures = measures;
        this.strings = strings;
        this.color = color;
    }

    public int getInstrument() {
        return instrument;
    }
    public void setInstrument(int instrument) {
        this.instrument = instrument;
    }
    public List getMeasures() {
        return measures;
    }
    public void setMeasures(List measures) {
        this.measures = measures;
    }    
    public int getChannel() {
        return channel;
    }
    public void setChannel(int channel) {
        this.channel = channel;
    }
    
    public List getStrings() {
        return strings;
    }
    public void setStrings(List strings) {
        this.strings = strings;
    }
    
    
    public TrackColor getColor() {
		return color;
	}

	public void setColor(TrackColor color) {
		this.color = color;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public boolean isPercusionTrack(){
        return (getChannel() == getDefaultPercusionChannel());
    }

    
    public static int getDefaultPercusionChannel(){
        return 9;
    }
}
